@@ -79,9 +79,6 @@ class ThetaClient:
         _verify_java()
 
         if launch:
-            if passwd.__contains__('%') or passwd.__contains__('?') or passwd.__contains__(' '):
-                raise ConnectionError('Unable to connect! Your password contains illegal characters: %, ?, or  (space).'
-                                      'Please change it at https://thetadata.net -> login -> forgot password.')
             if username == "default" or passwd == "default":
                 print("You are using the free version of Theta Data. You are currently limited to "
                       "20 requests / minute. A data subscription can be purchased at https://thetadata.net. "
